==> aroundme_0_7_5.zip: aroundme_0_7_5/aroundme/batch/config/batch.config.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


// CHARTS ------------------------------------------------------------------------
$batch_config = array();
$batch_config['24_hour_activity']['color']['background']['red'] 			= 255;
$batch_config['24_hour_activity']['color']['background']['green'] 			= 255;
$batch_config['24_hour_activity']['color']['background']['blue'] 			= 255;

$batch_config['24_hour_activity']['color']['foreground']['red'] 			= 244;
$batch_config['24_hour_activity']['color']['foreground']['green'] 			= 148;
$batch_config['24_hour_activity']['color']['foreground']['blue'] 			= 178;

$batch_config['24_hour_activity']['color']['grids']['red'] 					= 51;
$batch_config['24_hour_activity']['color']['grids']['green'] 				= 51;
$batch_config['24_hour_activity']['color']['grids']['blue'] 				= 51;

$batch_config['24_hour_activity']['color']['grids_background']['red']		= 255;
$batch_config['24_hour_activity']['color']['grids_background']['green']		= 255;
$batch_config['24_hour_activity']['color']['grids_background']['blue']		= 255;

$batch_config['24_hour_activity']['width']									= 350;
$batch_config['24_hour_activity']['height']									= 150;

$batch_config['24_hour_activity']['padding']['left']						= 10;
$batch_config['24_hour_activity']['padding']['right']						= 10;
$batch_config['24_hour_activity']['padding']['top']							= 10;
$batch_config['24_hour_activity']['padding']['bottom']						= 10;

$batch_config['24_hour_activity']['name']									= dirname(__FILE__) . '/../../' . $core_config['file']['dir'] . 'core/chart_24_hour_activity.png';


$batch_config['30_day_activity']['color']['background']['red'] 				= 255;
$batch_config['30_day_activity']['color']['background']['green'] 			= 255;
$batch_config['30_day_activity']['color']['background']['blue'] 			= 255;

$batch_config['30_day_activity']['color']['foreground']['red'] 				= 244;
$batch_config['30_day_activity']['color']['foreground']['green'] 			= 148;
$batch_config['30_day_activity']['color']['foreground']['blue'] 			= 178;

$batch_config['30_day_activity']['color']['grids']['red'] 					= 51;
$batch_config['30_day_activity']['color']['grids']['green'] 				= 51;
$batch_config['30_day_activity']['color']['grids']['blue'] 					= 51;

$batch_config['30_day_activity']['color']['grids_background']['red']		= 255;
$batch_config['30_day_activity']['color']['grids_background']['green']		= 255;
$batch_config['30_day_activity']['color']['grids_background']['blue']		= 255;

$batch_config['30_day_activity']['width']									= 350;
$batch_config['30_day_activity']['height']									= 200;

$batch_config['30_day_activity']['pile_space']								= 11;
$batch_config['30_day_activity']['pile_width']								= 6;
$batch_config['30_day_activity']['pile_scale']								= 0.75;

$batch_config['30_day_activity']['padding']['left']							= 10;
$batch_config['30_day_activity']['padding']['right']						= 10;
$batch_config['30_day_activity']['padding']['top']							= 10;
$batch_config['30_day_activity']['padding']['bottom']						= 10;

$batch_config['30_day_activity']['name']									= dirname(__FILE__) . '/../../' . $core_config['file']['dir'] . 'core/chart_30_day_activity.png';


$batch_config['latest_activity']['color']['background']['red'] 				= 255;
$batch_config['latest_activity']['color']['background']['green'] 			= 255;
$batch_config['latest_activity']['color']['background']['blue'] 			= 255;

$batch_config['latest_activity']['color']['foreground']['red'] 				= 244;
$batch_config['latest_activity']['color']['foreground']['green'] 			= 148;
$batch_config['latest_activity']['color']['foreground']['blue'] 			= 178;

$batch_config['latest_activity']['color']['grids']['red'] 					= 51;
$batch_config['latest_activity']['color']['grids']['green'] 				= 51;
$batch_config['latest_activity']['color']['grids']['blue'] 					= 51;

$batch_config['latest_activity']['color']['grids_background']['red']		= 255;
$batch_config['latest_activity']['color']['grids_background']['green']		= 255;
$batch_config['latest_activity']['color']['grids_background']['blue']		= 255;

$batch_config['latest_activity']['width']									= 350;
$batch_config['latest_activity']['height']									= 140;

$batch_config['latest_activity']['padding']['left']							= 10;
$batch_config['latest_activity']['padding']['right']						= 10;
$batch_config['latest_activity']['padding']['top']							= 10;
$batch_config['latest_activity']['padding']['bottom']						= 10;

$batch_config['latest_activity']['name']									= dirname(__FILE__) . '/../../' . $core_config['file']['dir'] . 'core/latest_activity.png';

$batch_config['people_by_location']['color']['background']['red'] 			= 255;
$batch_config['people_by_location']['color']['background']['green'] 		= 255;
$batch_config['people_by_location']['color']['background']['blue'] 			= 255;

$batch_config['people_by_location']['color']['foreground']['red'] 			= 244;
$batch_config['people_by_location']['color']['foreground']['green'] 		= 148;
$batch_config['people_by_location']['color']['foreground']['blue'] 			= 178;

$batch_config['people_by_location']['color']['foreground2']['red'] 			= 241;
$batch_config['people_by_location']['color']['foreground2']['green'] 		= 238;
$batch_config['people_by_location']['color']['foreground2']['blue'] 		= 240;

$batch_config['people_by_location']['color']['grids']['red'] 				= 51;
$batch_config['people_by_location']['color']['grids']['green'] 				= 51;
$batch_config['people_by_location']['color']['grids']['blue'] 				= 51;

$batch_config['people_by_location']['color']['grids_background']['red']		= 255;
$batch_config['people_by_location']['color']['grids_background']['green']	= 255;
$batch_config['people_by_location']['color']['grids_background']['blue']	= 255;

$batch_config['people_by_location']['width']								= 350;
$batch_config['people_by_location']['height']								= 100;
$batch_config['people_by_location']['scale_factor']							= 0.4;

$batch_config['people_by_location']['padding']['left']						= 10;
$batch_config['people_by_location']['padding']['right']						= 10;
$batch_config['people_by_location']['padding']['top']						= 10;
$batch_config['people_by_location']['padding']['bottom']					= 10;

$batch_config['people_by_location']['name']									= dirname(__FILE__) . '/../../' . $core_config['file']['dir'] . 'core/chart_people_by_location.png';

// EMAIL ----------------------------------------------------------------
// number of emails to be sent per batch
$batch_config['nr_per_batch'] = 											25;

?>

==> aroundme_0_7_7.zip: aroundme_0_7_7/aroundme/batch/config/batch.config.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


// CHARTS ------------------------------------------------------------------------
$batch_config = array();
$batch_config['24_hour_activity']['color']['background']['red'] 			= 255;
$batch_config['24_hour_activity']['color']['background']['green'] 			= 255;
$batch_config['24_hour_activity']['color']['background']['blue'] 			= 255;

$batch_config['24_hour_activity']['color']['foreground']['red'] 			= 244;
$batch_config['24_hour_activity']['color']['foreground']['green'] 			= 148;
$batch_config['24_hour_activity']['color']['foreground']['blue'] 			= 178;

$batch_config['24_hour_activity']['color']['grids']['red'] 					= 51;
$batch_config['24_hour_activity']['color']['grids']['green'] 				= 51;
$batch_config['24_hour_activity']['color']['grids']['blue'] 				= 51;

$batch_config['24_hour_activity']['color']['grids_background']['red']		= 255;
$batch_config['24_hour_activity']['color']['grids_background']['green']		= 255;
$batch_config['24_hour_activity']['color']['grids_background']['blue']		= 255;

$batch_config['24_hour_activity']['width']									= 350;
$batch_config['24_hour_activity']['height']									= 150;

$batch_config['24_hour_activity']['padding']['left']						= 10;
$batch_config['24_hour_activity']['padding']['right']						= 10;
$batch_config['24_hour_activity']['padding']['top']							= 10;
$batch_config['24_hour_activity']['padding']['bottom']						= 10;

$batch_config['24_hour_activity']['name']									= dirname(__FILE__) . '/../../' . $core_config['file']['dir'] . 'core/chart_24_hour_activity.png';


$batch_config['30_day_activity']['color']['background']['red'] 				= 255;
$batch_config['30_day_activity']['color']['background']['green'] 			= 255;
$batch_config['30_day_activity']['color']['background']['blue'] 			= 255;

$batch_config['30_day_activity']['color']['foreground']['red'] 				= 244;
$batch_config['30_day_activity']['color']['foreground']['green'] 			= 148;
$batch_config['30_day_activity']['color']['foreground']['blue'] 			= 178;

$batch_config['30_day_activity']['color']['grids']['red'] 					= 51;
$batch_config['30_day_activity']['color']['grids']['green'] 				= 51;
$batch_config['30_day_activity']['color']['grids']['blue'] 					= 51;

$batch_config['30_day_activity']['color']['grids_background']['red']		= 255;
$batch_config['30_day_activity']['color']['grids_background']['green']		= 255;
$batch_config['30_day_activity']['color']['grids_background']['blue']		= 255;

$batch_config['30_day_activity']['width']									= 350;
$batch_config['30_day_activity']['height']									= 200;

$batch_config['30_day_activity']['pile_space']								= 11;
$batch_config['30_day_activity']['pile_width']								= 6;
$batch_config['30_day_activity']['pile_scale']								= 0.75;

$batch_config['30_day_activity']['padding']['left']							= 10;
$batch_config['30_day_activity']['padding']['right']						= 10;
$batch_config['30_day_activity']['padding']['top']							= 10;
$batch_config['30_day_activity']['padding']['bottom']						= 10;

$batch_config['30_day_activity']['name']									= dirname(__FILE__) . '/../../' . $core_config['file']['dir'] . 'core/chart_30_day_activity.png';


$batch_config['latest_activity']['color']['background']['red'] 				= 255;
$batch_config['latest_activity']['color']['background']['green'] 			= 255;
$batch_config['latest_activity']['color']['background']['blue'] 			= 255;

$batch_config['latest_activity']['color']['foreground']['red'] 				= 244;
$batch_config['latest_activity']['color']['foreground']['green'] 			= 148;
$batch_config['latest_activity']['color']['foreground']['blue'] 			= 178;

$batch_config['latest_activity']['color']['grids']['red'] 					= 51;
$batch_config['latest_activity']['color']['grids']['green'] 				= 51;
$batch_config['latest_activity']['color']['grids']['blue'] 					= 51;

$batch_config['latest_activity']['color']['grids_background']['red']		= 255;
$batch_config['latest_activity']['color']['grids_background']['green']		= 255;
$batch_config['latest_activity']['color']['grids_background']['blue']		= 255;

$batch_config['latest_activity']['width']									= 350;
$batch_config['latest_activity']['height']									= 140;

$batch_config['latest_activity']['padding']['left']							= 10;
$batch_config['latest_activity']['padding']['right']						= 10;
$batch_config['latest_activity']['padding']['top']							= 10;
$batch_config['latest_activity']['padding']['bottom']						= 10;

$batch_config['latest_activity']['name']									= dirname(__FILE__) . '/../../' . $core_config['file']['dir'] . 'core/latest_activity.png';

$batch_config['people_by_location']['color']['background']['red'] 			= 255;
$batch_config['people_by_location']['color']['background']['green'] 		= 255;
$batch_config['people_by_location']['color']['background']['blue'] 			= 255;

$batch_config['people_by_location']['color']['foreground']['red'] 			= 244;
$batch_config['people_by_location']['color']['foreground']['green'] 		= 148;
$batch_config['people_by_location']['color']['foreground']['blue'] 			= 178;

$batch_config['people_by_location']['color']['foreground2']['red'] 			= 241;
$batch_config['people_by_location']['color']['foreground2']['green'] 		= 238;
$batch_config['people_by_location']['color']['foreground2']['blue'] 		= 240;

$batch_config['people_by_location']['color']['grids']['red'] 				= 51;
$batch_config['people_by_location']['color']['grids']['green'] 				= 51;
$batch_config['people_by_location']['color']['grids']['blue'] 				= 51;

$batch_config['people_by_location']['color']['grids_background']['red']		= 255;
$batch_config['people_by_location']['color']['grids_background']['green']	= 255;
$batch_config['people_by_location']['color']['grids_background']['blue']	= 255;

$batch_config['people_by_location']['width']								= 350;
$batch_config['people_by_location']['height']								= 100;
$batch_config['people_by_location']['scale_factor']							= 0.4;

$batch_config['people_by_location']['padding']['left']						= 10;
$batch_config['people_by_location']['padding']['right']						= 10;
$batch_config['people_by_location']['padding']['top']						= 10;
$batch_config['people_by_location']['padding']['bottom']					= 10;

$batch_config['people_by_location']['name']									= dirname(__FILE__) . '/../../' . $core_config['file']['dir'] . 'core/chart_people_by_location.png';

// EMAIL ----------------------------------------------------------------
// number of emails to be sent per batch
$batch_config['nr_per_batch'] = 											25;

// LOGGING ---------------------------------------------------------------
// set to true to write to log file / false not to.
$batch_config['log'] = 								true;
// http path to scripts directory- only used by php when batch processing
//$core_config['node']['url']['www_path'] = 			"http://www.your-domain.org/aroundme/";
$batch_config['node']['url']['www_path'] = 			"http://192.168.0.131/dev/am_0_7_dev/aroundme/";

?>
